Common types and utilities for the Zoi package manager.
This crate provides shared data structures, traits, and user experience (UX) components that are used across multiple Zoi crates, including the main CLI and Zoi Mini.
Modules
- ux
- User experience data structures and utilities. User experience (UX) data structures for Zoi.
Structs
- Source
Install Options - Options for installing packages from source.
Traits
- Runnable
- A trait for subcommands that can be executed.